reposmgr
--------

(Very) simple management command(s) to read files that stores
information about repositories that should be stored in certain place
in the system. Read only (so suitable for deployments).

